@@ -17,8 +17,9 @@ bool result_active(result_ptr const& r) {
 bool result_completed(result_ptr const& r) { return r->complete(); }
 
 // [[Rcpp::export]]
-result_ptr new_result(connection_ptr const& p, std::string const& sql) {
-  return result_ptr(new odbc::odbc_result(*p, sql));
+result_ptr new_result(
+    connection_ptr const& p, std::string const& sql, const bool immediate) {
+  return result_ptr(new odbc::odbc_result(*p, sql, immediate));
 }
 
 // [[Rcpp::export]]
@@ -44,16 +45,22 @@ Rcpp::DataFrame result_column_info(result_ptr const& r) {
 }
 
 // [[Rcpp::export]]
-void result_bind(result_ptr const& r, List const& params) {
-  r->bind_list(params, false);
+void result_bind(result_ptr const& r, List const& params, size_t batch_rows) {
+  r->bind_list(params, false, batch_rows);
 }
 
 // [[Rcpp::export]]
 void result_execute(result_ptr const& r) { r->execute(); }
 
 // [[Rcpp::export]]
-void result_insert_dataframe(result_ptr const& r, DataFrame const& df) {
-  r->bind_list(df);
+void result_insert_dataframe(
+    result_ptr const& r, DataFrame const& df, size_t batch_rows) {
+  r->bind_list(df, true, batch_rows);
+}
+
+// [[Rcpp::export]]
+void result_describe_parameters(result_ptr const& r, DataFrame const& df) {
+  r->describe_parameters(df);
 }
 
 // [[Rcpp::export]]
